@@ -6,7 +6,7 @@
 # This file is part of HDF5.  The full HDF5 copyright notice, including
 # terms governing use, modification, and redistribution, is contained in
 # the COPYING file, which can be found at the root of the source code
-# distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.
+# distribution tree, or in https://www.hdfgroup.org/licenses.
 # If you do not have access to either file, you may request a copy from
 # help@hdfgroup.org.
 
@@ -18,7 +18,7 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #                                                                               #
 # This script will compile and run the c examples from source files installed   #
-# in /usr/local/share/examples/hdf5/c using h5cc or h5pc.  The order for running                 #
+# in /usr/pkg/share/examples/hdf5/c using h5cc or h5pc.  The order for running                 #
 # programs with RunTest in the MAIN section below is taken from the Makefile.   #
 # The order is important since some of the test programs use data files created #
 # by earlier test programs.  Any future additions should be placed accordingly. #
@@ -42,8 +42,8 @@ EXIT_FAILURE=1
 # $() won't clobbered it.
 #
 prefix_relto_examplesdir=$(
-prefix=/usr/local
-examplesdir=/usr/local/share/examples/hdf5
+prefix=/usr/pkg
+examplesdir=/usr/pkg/share/examples/hdf5
 if [ ${examplesdir##${prefix}/} != ${examplesdir} ]; then
 	echo $(echo ${examplesdir##${prefix}/} | \
 	    sed 's,[^/][^/]*,..,g')
@@ -53,7 +53,7 @@ fi
 )
 
 # Where the tool is installed.
-# default is relative path to installed location of the tools 
+# default is relative path to installed location of the tools
 prefix="${prefix:-../${prefix_relto_examplesdir}}"
 PARALLEL=no             # Am I in parallel mode?
 AR="ar"
@@ -149,6 +149,11 @@ then
         rm h5_extlink &&\
         RunTest h5_elink_unix2win &&\
         rm h5_elink_unix2win &&\
+        OLD_DEBUG_STRING=$HDF5_DEBUG &&\
+        export HDF5_DEBUG="+all +trace +ttimes" &&\
+        RunTest h5_debug_trace &&\
+        HDF5_DEBUG=$OLD_DEBUG_STRING &&\
+        rm h5_debug_trace &&\
         RunTest h5_shared_mesg &&\
         rm h5_shared_mesg &&\
         RunTest h5_vds-eiger &&\
@@ -179,5 +184,5 @@ rm *.h5
 rm -rf red blue u2w
 echo
 
-exit $EXIT_VALUE 
+exit $EXIT_VALUE
 
